# Credits

## Original author

- [Virginie Zell](https://gitlab.com/VirginieZ)

## Contributors

- [Étienne Lac](https://gitlab.com/etienne.lac) (etienne.lac@safrangroup.com)
- [Duc Trung Lê](https://gitlab.com/ductrungle)
